@@ -1076,7 +1076,7 @@ haze_media_stream_new_native_candidate (TpSvcMediaStreamHandler *iface,
       if (proto == TP_MEDIA_STREAM_BASE_PROTO_UDP)
         protocol = PURPLE_MEDIA_NETWORK_PROTOCOL_UDP;
       else if (proto == TP_MEDIA_STREAM_BASE_PROTO_TCP)
-        protocol = PURPLE_MEDIA_NETWORK_PROTOCOL_TCP;
+        protocol = PURPLE_MEDIA_NETWORK_PROTOCOL_TCP_PASSIVE;
       else
         DEBUG ("Unknown network protocol");
 
@@ -1345,7 +1345,7 @@ haze_media_stream_codecs_updated (TpSvcMediaStreamHandler *iface,
 
   if (self->priv->codecs == NULL)
     {
-      GError e = { TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+      GError e = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
           "CodecsUpdated may only be called once an initial set of codecs "
           "has been set" };
 
