@@ -137,8 +137,8 @@ def test(q, bus, conn, stream):
             EventPattern('dbus-return', method='AddMembers'),
             )
     assertEquals('duncan@scotland.lit', iq.stanza.query.item['jid'])
-    groups = set([str(x) for x in xpath.queryForNodes('/iq/query/item/group',
-        iq.stanza)])
+    groups = {str(x) for x in xpath.queryForNodes('/iq/query/item/group',
+        iq.stanza)}
     assertLength(2, groups)
     assertContains(default_group_name, groups)
     assertContains('Scots', groups)
@@ -154,8 +154,8 @@ def test(q, bus, conn, stream):
             EventPattern('dbus-return', method='RemoveMembers'),
             )
     assertEquals('duncan@scotland.lit', iq.stanza.query.item['jid'])
-    groups = set([str(x) for x in xpath.queryForNodes('/iq/query/item/group',
-        iq.stanza)])
+    groups = {str(x) for x in xpath.queryForNodes('/iq/query/item/group',
+        iq.stanza)}
     assertLength(1, groups)
     assertContains('Scots', groups)
 
@@ -178,15 +178,15 @@ def test(q, bus, conn, stream):
             )
 
     assertEquals('romeo@montague.lit', iq1.stanza.query.item['jid'])
-    groups = set([str(x) for x in xpath.queryForNodes('/iq/query/item/group',
-        iq1.stanza)])
+    groups = {str(x) for x in xpath.queryForNodes('/iq/query/item/group',
+        iq1.stanza)}
     assertLength(2, groups)
     assertContains('Still alive', groups)
     assertContains(default_group_name, groups)
 
     assertEquals('romeo@montague.lit', iq2.stanza.query.item['jid'])
-    groups = set([str(x) for x in xpath.queryForNodes('/iq/query/item/group',
-        iq2.stanza)])
+    groups = {str(x) for x in xpath.queryForNodes('/iq/query/item/group',
+        iq2.stanza)}
     assertLength(1, groups)
     assertContains(default_group_name, groups)
 
@@ -202,8 +202,8 @@ def test(q, bus, conn, stream):
             EventPattern('dbus-return', method='RemoveMembers'),
             )
     assertEquals('juliet@capulet.lit', iq.stanza.query.item['jid'])
-    groups = set([str(x) for x in xpath.queryForNodes('/iq/query/item/group',
-        iq.stanza)])
+    groups = {str(x) for x in xpath.queryForNodes('/iq/query/item/group',
+        iq.stanza)}
     assertLength(1, groups)
     assertContains('Capulets', groups)
 
