@@ -13,9 +13,6 @@ import constants as cs
 import ns
 
 def test(q, bus, conn, stream):
-    conn.Connect()
-    q.expect('dbus-signal', signal='StatusChanged',
-            args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED])
     self_handle = conn.GetSelfHandle()
 
     # Close all Group channels to get a clean slate, so we can rely on
